@@ -6,18 +6,25 @@ utils::globalVariables(
     "Est",
     "ci.low",
     "ci.up",
-    "df.denom",
-    "df.num",
-    "effect_size",
+    "effsize",
+    "effectsize",
     "estimate",
-    "int_df",
     "rowid",
     "statistic",
     "std.error",
     "term",
     ".counts",
     "df",
-    "df.error"
+    "df.error",
+    "k.parameter",
+    "effsize.text",
+    "method",
+    ".f",
+    ".f.es",
+    "bf10",
+    "estimate.LB",
+    "estimate.UB",
+    "r2.component"
   ),
   package = "statsExpressions",
   add = FALSE
