@@ -36,28 +36,6 @@ ipmisc::tibble
 #' @importFrom ipmisc as_tibble
 ipmisc::as_tibble
 
-# ----------------------- tidyBF -------------------------------------
-
-#' @export
-#' @importFrom tidyBF bf_contingency_tab
-tidyBF::bf_contingency_tab
-
-#' @export
-#' @importFrom tidyBF bf_ttest
-tidyBF::bf_ttest
-
-#' @export
-#' @importFrom tidyBF bf_meta_random
-tidyBF::bf_meta_random
-
-#' @export
-#' @importFrom tidyBF bf_corr_test
-tidyBF::bf_corr_test
-
-#' @export
-#' @importFrom tidyBF bf_oneway_anova
-tidyBF::bf_oneway_anova
-
 # ----------------------- easystats -------------------------------------
 
 #' @export
