@@ -1,15 +1,15 @@
 
 # parametric -----------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "expr_t_onesample parametric works",
   code = {
-    testthat::skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
 
     # Hedge's g and non-central
     set.seed(123)
     using_function1 <-
-      statsExpressions::expr_t_onesample(
+      expr_t_onesample(
         data = dplyr::sample_frac(movies_long, 0.05),
         x = length,
         test.value = 120,
@@ -51,7 +51,7 @@ testthat::test_that(
     set.seed(123)
     using_function2 <-
       suppressWarnings(
-        statsExpressions::expr_t_onesample(
+        expr_t_onesample(
           data = dplyr::sample_frac(movies_long, 0.05),
           x = "length",
           test.value = 120,
@@ -93,28 +93,28 @@ testthat::test_that(
       )
 
     # testing overall call
-    testthat::expect_identical(using_function1, results1)
-    testthat::expect_identical(using_function2, results2)
+    expect_identical(using_function1, results1)
+    expect_identical(using_function2, results2)
   }
 )
 
 # non-parametric -----------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "expr_t_onesample non-parametric works",
   code = {
-    testthat::skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
 
     # statsExpressions output
     set.seed(123)
     using_function <-
-      statsExpressions::expr_t_onesample(
+      suppressWarnings(expr_t_onesample(
         data = ToothGrowth,
         x = len,
         test.value = 20,
         type = "np",
         k = 4
-      )
+      ))
 
     # expected output
     set.seed(123)
@@ -129,14 +129,14 @@ testthat::test_that(
           " = ",
           "0.3227",
           ", ",
-          widehat(italic("r")),
+          widehat(italic("r"))["biserial"]^"rank",
           " = ",
-          "-0.1282",
+          "-0.1486",
           ", CI"["95%"],
           " [",
-          "-0.3827",
+          "-0.4584",
           ", ",
-          "0.1522",
+          "0.1206",
           "]",
           ", ",
           italic("n")["obs"],
@@ -146,12 +146,12 @@ testthat::test_that(
       )
 
     # testing overall call
-    testthat::expect_identical(using_function, results)
+    expect_identical(using_function, results)
 
     # statsExpressions output
     set.seed(123)
     using_function2 <-
-      statsExpressions::expr_t_onesample(
+      expr_t_onesample(
         data = ggplot2::msleep,
         x = names(ggplot2::msleep)[10],
         test.value = 0.25,
@@ -170,14 +170,14 @@ testthat::test_that(
           " = ",
           "1.253e-05",
           ", ",
-          widehat(italic("r")),
+          widehat(italic("r"))["biserial"]^"rank",
           " = ",
-          "-0.5840",
+          "-0.6717",
           ", CI"["95%"],
           " [",
-          "-0.8133",
+          "-0.9052",
           ", ",
-          "-0.3768",
+          "-0.4177",
           "]",
           ", ",
           italic("n")["obs"],
@@ -187,29 +187,28 @@ testthat::test_that(
       )
 
     # testing overall call
-    testthat::expect_identical(using_function2, results2)
+    expect_identical(using_function2, results2)
   }
 )
 
 
 # robust -----------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "expr_t_onesample robust works",
   code = {
-    testthat::skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
 
     # statsExpressions output
     set.seed(123)
     using_function <-
-      statsExpressions::expr_t_onesample(
+      expr_t_onesample(
         data = anscombe,
         x = "x1",
         test.value = 8,
         type = "r",
         k = 4,
-        conf.level = 0.99,
-        messages = TRUE
+        conf.level = 0.99
       )
 
     # expected output
@@ -217,18 +216,23 @@ testthat::test_that(
     results <-
       ggplot2::expr(
         paste(
-          italic("M")["robust"],
+          italic("t")["bootstrapped"],
+          " = ",
+          "0.8748",
+          ", ",
+          italic("p"),
+          " = ",
+          "0.2500",
+          ", ",
+          widehat(mu)["trimmed"],
           " = ",
           "9.0000",
           ", CI"["99%"],
           " [",
-          "6.0128",
+          "4.4493",
           ", ",
-          "11.6299",
-          "], ",
-          italic("p"),
-          " = ",
-          "0.3000",
+          "13.5507",
+          "]",
           ", ",
           italic("n")["obs"],
           " = ",
@@ -237,83 +241,133 @@ testthat::test_that(
       )
 
     # testing overall call
-    testthat::expect_identical(using_function, results)
+    expect_identical(using_function, results)
+
+    # statsExpressions output
+    set.seed(123)
+    using_function2 <-
+      expr_t_onesample(
+        data = ggplot2::msleep,
+        x = brainwt,
+        test.value = 0.1,
+        type = "r",
+        k = 4,
+        conf.level = 0.90
+      )
+
+    # expected output
+    set.seed(123)
+    results2 <-
+      ggplot2::expr(
+        paste(
+          italic("t")["bootstrapped"],
+          " = ",
+          "-1.4272",
+          ", ",
+          italic("p"),
+          " = ",
+          "0.2000",
+          ", ",
+          widehat(mu)["trimmed"],
+          " = ",
+          "0.0660",
+          ", CI"["90%"],
+          " [",
+          "0.0201",
+          ", ",
+          "0.1119",
+          "]",
+          ", ",
+          italic("n")["obs"],
+          " = ",
+          "56"
+        )
+      )
+
+    # testing overall call
+    expect_identical(using_function2, results2)
   }
 )
 
 # bayes factor -----------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "expr_t_onesample bayes factor works",
   code = {
-    testthat::skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
+    skip_on_cran()
 
-    # statsExpressions output
+    # extracting results from where this function is implemented
     set.seed(123)
-    using_function <-
-      statsExpressions::expr_t_onesample(
-        data = anscombe,
-        x = "x2",
-        test.value = 8,
-        type = "bf"
-      )
-
-    # expected output
-    set.seed(123)
-    results <-
-      tidyBF::bf_ttest(
-        data = anscombe,
-        x = "x2",
-        test.value = 8,
-        type = "bf",
-        output = "expr"
-      )
-
-    # testing overall call
-    testthat::expect_identical(using_function, results)
-
-    # statsExpressions output
-    set.seed(123)
-    using_function2 <-
-      statsExpressions::expr_t_onesample(
-        data = ggplot2::msleep,
-        x = "brainwt",
-        test.value = 0.25,
-        type = "bf",
-        k = 4
-      )
-
-    # expected result
-    set.seed(123)
-    results2 <-
-      tidyBF::bf_ttest(
-        data = ggplot2::msleep,
-        x = "brainwt",
-        test.value = 0.25,
-        type = "bf",
-        k = 4,
-        output = "expression"
-      )
-
-    # testing overall call
-    testthat::expect_identical(using_function2, results2)
-  }
-)
-
-
-# dataframe -----------------------------------------------------------
-
-testthat::test_that(
-  desc = "dataframe",
-  code = {
-    testthat::expect_s3_class(
-      statsExpressions::expr_t_onesample(
-        data = dplyr::sample_frac(movies_long, 0.05),
-        x = length,
-        test.value = 120,
+    df_results <-
+      expr_t_onesample(
+        type = "bayes",
+        data = iris,
+        x = Petal.Length,
+        y = NULL,
+        test.value = 5.5,
+        bf.prior = 0.99,
         output = "dataframe"
-      ),
-      "tbl_df"
+      )
+
+    # check Bayes factor values
+    expect_equal(df_results$bf10[[1]], 5.958171e+20, tolerance = 0.001)
+    expect_equal(df_results$log_e_bf10[[1]], 47.83647, tolerance = 0.001)
+
+    # extracting subtitle (without NA)
+    set.seed(123)
+    subtitle <-
+      expr_t_onesample(
+        type = "bayes",
+        data = iris,
+        x = "Petal.Length",
+        y = NULL,
+        test.value = 5.5,
+        bf.prior = 0.99,
+        output = "expression",
+        centrality = "mean",
+        conf.level = 0.90
+      )
+
+    expect_type(subtitle, "language")
+
+    expect_identical(
+      subtitle,
+      ggplot2::expr(
+        paste(
+          "log"["e"] * "(BF"["01"] * ") = " * "-47.84" * ", ",
+          widehat(italic(delta))["median"]^"posterior" * " = " * "1.76" * ", ",
+          "CI"["90%"]^"HDI" * " [" * "1.52" * ", " * "1.99" * "], ",
+          italic("r")["Cauchy"]^"JZS" * " = " * "0.99"
+        )
+      )
+    )
+
+    # extracting subtitle (with NA)
+    set.seed(123)
+    subtitle2 <-
+      expr_t_onesample(
+        type = "bayes",
+        data = ggplot2::msleep,
+        x = brainwt,
+        y = NULL,
+        test.value = 0.25,
+        bf.prior = 0.9,
+        k = 3,
+        output = "subtitle",
+        conf.method = "eti"
+      )
+
+    expect_identical(
+      subtitle2,
+      ggplot2::expr(
+        paste(
+          "log"["e"] * "(BF"["01"] * ") = " * "2.125" * ", ",
+          widehat(italic(delta))["median"]^"posterior" * " = " * "-0.018" * ", ",
+          "CI"["95%"]^"HDI" * " [" * "-0.265" * ", " * "0.242" * "], ",
+          italic("r")["Cauchy"]^"JZS" * " = " * "0.900"
+        )
+      )
     )
   }
 )
