@@ -1,10 +1,10 @@
 
 # loops - correlation ---------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "expr_corr_test works in loop",
   code = {
-    testthat::skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "3.6")
 
     col.name <- colnames(mtcars)
 
@@ -17,16 +17,16 @@ testthat::test_that(
         ))
       })
 
-    testthat::expect_equal(length(ls), 8L)
+    expect_equal(length(ls), 8L)
   }
 )
 
 # loops - one-sample ---------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "expr_onesample works in loop",
   code = {
-    testthat::skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "3.6")
 
     col.name <- colnames(mtcars)
 
@@ -39,17 +39,17 @@ testthat::test_that(
         ))
       })
 
-    testthat::expect_equal(length(ls), 12L)
+    expect_equal(length(ls), 12L)
   }
 )
 
 
 # loops - contingency tabs ---------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "expr_contingency_tab works in loop",
   code = {
-    testthat::skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "3.6")
 
     df <- dplyr::select(mtcars, am, cyl, vs)
     col.name <- colnames(df)
@@ -63,6 +63,6 @@ testthat::test_that(
         ))
       })
 
-    testthat::expect_equal(length(ls), 12L)
+    expect_equal(length(ls), 12L)
   }
 )
